| splits-class | R Documentation |
An S4 class to represent a split object
callAn image of the call that produced the object.
typeSplitting function employed to split cues.
formulaformula object of the model.
class_labelsA vector of length 2 containing the class labels. The second entry is referred to as the positive class.
weightsA numeric vector of length 2. The first entry denotes the weight of instances in the positive class, the second entry the weight of instances in the negative class.
training_dataData that was used to train the model
splitsRepresentation of the splits
priorThe proportion of objects in the positive class in the training set.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.