| tallyModel-class | R Documentation |
An S4 class to represent a tallying tree model
callAn image of the call that produced the object.
formulaformula object of the model.
parametersParameters used to train the tallying model.
performanceList showing fitting and cross-validated performance.
class_labelsA vector of length 2 containing the class labels. The first entry is referred to as the negative class, the second entry is referred to as the positive class.
weightsA numeric vector of length 2. The first entry denotes the weight of instances in the negative class, the second entry the weight of instances in the positive class.
priorThe proportion of objects in the positive class in the training set.
tallyRepresentation of the tallying model
split_functionHow numeric features are split when 'basic' method is used.
training_dataData that was used to train the model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.